@@ -101,7 +101,7 @@ where
 
         // register sample specific tags
         header.push_record(
-            b"##FORMAT=<ID=DP,Number=A,Type=Integer,\
+            b"##FORMAT=<ID=DP,Number=1,Type=Integer,\
               Description=\"Expected sequencing depth, while considering mapping uncertainty\">",
         );
         header.push_record(
@@ -113,7 +113,16 @@ where
               and P being the read position (^ = most found read position, * = any other position or position is irrelevant). \
               Posterior odds for alt allele of each fragment are given as extended Kass Raftery \
               scores: N=none, E=equal, B=barely, P=positive, S=strong, V=very strong (lower case if \
-              probability for correct mapping of fragment is <95%). Thereby we extend Kass Raftery scores with \
+              probability for correct mapping of fragment is <95%). Note that we extend Kass Raftery scores with \
+              a term for equality between the evidence of the two alleles (E=equal).\">",
+        );
+        header.push_record(
+            b"##FORMAT=<ID=SOBS,Number=A,Type=String,\
+              Description=\"Summary of simplified observations. Each entry is encoded as CB, with C being a count, \
+              B being the posterior odds for the alt allele. \
+              Posterior odds for alt allele of each fragment are given as extended Kass Raftery \
+              scores: N=none, E=equal, B=barely, P=positive, S=strong, V=very strong (lower case if \
+              probability for correct mapping of fragment is <95%). Note that we extend Kass Raftery scores with \
               a term for equality between the evidence of the two alleles (E=equal).\">",
         );
         header.push_record(
