@@ -254,10 +254,11 @@ impl Posterior for GenericPosterior {
         };
 
         // METHOD: filter out biases that are impossible to observe, (e.g. + without any + observation).
-        let possible_biases = event
-            .biases
-            .iter()
-            .filter(|bias| bias.is_possible(&data.pileups) && bias.is_informative(&data.pileups));
+        let possible_biases = event.biases.iter().filter(|bias| {
+            bias.is_possible(&data.pileups)
+                && bias.is_informative(&data.pileups)
+                && bias.is_likely(&data.pileups)
+        });
         LogProb::ln_sum_exp(
             &possible_biases
                 .cartesian_product(vaf_tree)
