@@ -1,6 +1,6 @@
 use std::cell::RefCell;
 use std::cmp;
-use std::collections::{BTreeMap, HashSet};
+use std::collections::HashSet;
 use std::str;
 
 use anyhow::Result;
@@ -688,6 +688,7 @@ impl Prior {
             }
             (p1, p2, c) if p1 % 2 == 0 && p2 % 2 == 0 && c == (p1 / 2 + p2 / 2) => {
                 // Default case, normal meiosis (child inherits one half from each parent).
+                // TODO derive other cases in a more generic way from this one!
                 prob_after_meiotic_split(p1 / 2, p2 / 2)
             }
             (p1, p2, c) if p1 % 2 == 0 && p2 == 1 && c == (p1 / 2 + p2) => {
@@ -698,6 +699,14 @@ impl Prior {
                 // Sex chromosome inheritance (one parent is e.g. diploid, the other haploid).
                 prob_after_meiotic_split(p1, p2 / 2)
             }
+            (p1, p2, c) if p1 == 2 && p2 == 1 && c == 1 => {
+                // Sex chromosome inheritance (one parent is e.g. diploid, the other haploid).
+                prob_after_meiotic_split(1, 0)
+            }
+            (p1, p2, c) if p1 == 1 && p2 == 2 && c == 1 => {
+                // Sex chromosome inheritance (one parent is e.g. diploid, the other haploid).
+                prob_after_meiotic_split(0, 1)
+            }
             (p1, p2, c) => {
                 // something went wrong, there are more chromosomes in the child than in the parents
                 // case 1: no separation in the first meiotic split (choose from all chromosomes of that parent)
